import sys

from django import VERSION as django_version

try:
    import psycopg2
    HAS_PSYCOPG2 = True
except ImportError:
    psycopg2 = None
    HAS_PSYCOPG2 = False

if sys.version < '3':
    text_type = unicode
    binary_type = str
    string_types = basestring
else:
    text_type = str
    binary_type = bytes
    string_types = str


def get_model_fields(model):
    if django_version < (1, 8, 0):
        return [(f.name, f) for f in model._meta.concrete_fields]
    return model._meta._forward_fields_map.items()


def get_related_model(field):
    if django_version < (1, 8, 0):
        return field.related.parent_model
    return field.related_model



def language_to_locale(language):
    """
    Converts django's `LANGUAGE_CODE` settings to a proper locale code.
    """
    tokens = language.split('-')
    if len(tokens) == 1:
        return tokens[0]
    return "%s_%s" % (tokens[0], tokens[1].upper())



from setuptools import find_packages, setup


VERSION = '1.0.0'

setup(
    name='django-fakery',
    version=VERSION,
    url='https://github.com/fcurella/django-factory/',
    author='Flavio Curella',
    author_email='flavio.curella@gmail.com',
    description='A model instances generator for Django',
    license='MIT',
    packages=find_packages(exclude=['*.tests']),
    platforms=["any"],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    install_requires=[
        "fake-factory==0.5.3",
        "Django>=1.7",
    ],
    test_suite='django_fakery.tests.runtests.runtests',
)
